@@ -11,7 +11,7 @@ from libreflow.baseflow.film import FilmCollection
 from libreflow.baseflow.task_manager import TaskManager
 
 from .entity_manager import EntityManager
-from .user import User
+from .user import User, Users
 from .film import Film
 from .shot import Sequence, Shot
 from .task import Task, Tasks
@@ -27,6 +27,10 @@ from .file import (
 class ProjectSettings(BaseProjectSettings):
 
     task_manager = flow.Child(TaskManager)
+    # image_sequence_prefixes = flow.OrderedStringSetParam()
+    shot_types = flow.OrderedStringSetParam()
+    shot_indexes = flow.OrderedStringSetParam()
+    shot_versions = flow.OrderedStringSetParam()
 
 
 class Admin(BaseAdmin):
@@ -80,6 +84,8 @@ class Project(BaseProject, flow.InjectionProvider):
             return TrackedFolderRevision
         elif slot_name == 'libreflow.baseflow.users.User':
             return User
+        elif slot_name == 'libreflow.baseflow.users.Users':
+            return Users
         elif slot_name == 'libreflow.baseflow.ProjectSettings':
             return ProjectSettings
     
