@@ -11,7 +11,7 @@ from kabaret.flow_contextual_dict import ContextualView, get_contextual_dict
 from kabaret.subprocess_manager.flow import RunAction
 
 from libreflow import baseflow
-from libreflow.baseflow.file import CreateDefaultFilesAction
+from libreflow.baseflow.file import CreateDefaultFilesAction, FileRevisionNameChoiceValue
 
 from libreflow.utils.b3d import wrap_python_expr
 from libreflow.utils.flow import get_context_value
@@ -187,7 +187,11 @@ class LayoutDependencies(flow.DynamicMap):
     def _get_assets_data(self):
         kitsu_api = self.root().project().kitsu_api()
         kitsu_casting = kitsu_api.get_shot_casting(self._shot.name(), self._sequence.name())
-        casting = dict()
+
+        if kitsu_casting is None:
+            return {}
+
+        casting = {}
         
         # Kitsu assets
         for asset in kitsu_casting:
@@ -742,11 +746,128 @@ class CreateAnimationScene(flow.Action):
         files.touch()
 
 
+class CreateCleanScene(flow.Action):
+
+    _dept = flow.Parent()
+
+    def __init__(self, parent, name):
+        super(CreateCleanScene, self).__init__(parent, name)
+        self._anim_file = None
+        self._anim_revision = None
+        self._needs_refresh = True
+    
+    def get_file(self):
+        self._compute_anim()
+        return self._anim_file
+
+    def get_revision(self):
+        self._compute_anim()
+        return self._anim_revision
+    
+    def _compute_anim(self):
+        if self._needs_refresh:
+            self._anim_file = None
+            self._anim_revision = None
+            
+            if self._dept.files.has_file('animation', 'blend'):
+                self._anim_file = self._dept.files['animation_blend']
+                self._anim_revision = self._anim_file.get_head_revision()
+            
+            self._needs_refresh = False
+    
+    def needs_dialog(self):
+        self._anim_file = None
+        self._anim_revision = None
+        self._needs_refresh = True
+        return True
+
+    def get_buttons(self):
+        anim_exists = False
+        msg = '<h2><font color=#D5000D>No animation scene available</font></h2>'
+
+        r = self.get_revision()
+        if r is not None:
+            if r.get_sync_status() == 'Available':
+                anim_exists = True
+                msg = '<h2>Create clean-up scene</h2>'
+            elif r.get_sync_status(exchange=True) == 'Available':
+                anim_exists = True
+                msg = (
+                    '<h2>Create clean-up scene</h2>'
+                    '<h3>Last revision of animation not available '
+                    'yet: the revision will be downloaded first.</h3>'
+                )
+        
+        if not anim_exists:
+            self.message.set((
+                '<h2><font color=#D5000D>No animation '
+                'scene available</font></h2>'
+            ))
+            return ['Cancel']
+        
+        self.message.set(msg)
+        return ['Create', 'Cancel']
+    
+    def run(self, button):
+        if button == 'Cancel':
+            return
+        
+        anim_revision = self.get_revision()
+
+        if anim_revision.get_sync_status() != 'Available':
+            self._download(anim_revision)
+        
+        if not self._dept.files.has_file('clean', 'blend'):
+            clean_file = self._dept.files.add_file(
+                'clean', 'blend', tracked=True
+            )
+        else:
+            clean_file = self._dept.files['clean_blend']
+        
+        clean_revision = clean_file.add_revision()
+        clean_revision_path = clean_revision.get_path()
+        revision_dir = os.path.dirname(clean_revision_path)
+
+        if not os.path.exists(revision_dir):
+            os.makedirs(revision_dir)
+        
+        shutil.copy2(anim_revision.get_path(), clean_revision_path)
+        clean_file.last_revision_oid.set(clean_revision.oid())
+        self._upload(clean_revision)
+
+    def _download(self, revision):
+        current_site = self.root().project().get_current_site()
+
+        dl_job = current_site.get_queue().submit_job(
+            emitter_oid=revision.oid(),
+            user=self.root().project().get_user_name(),
+            studio=current_site.name(),
+            job_type='Download',
+            init_status='WAITING'
+        )
+        sync_manager = self.root().project().get_sync_manager()
+        sync_manager.process(dl_job)
+    
+    def _upload(self, revision):
+        current_site = self.root().project().get_current_site()
+
+        ul_job = current_site.get_queue().submit_job(
+            emitter_oid=revision.oid(),
+            user=self.root().project().get_user_name(),
+            studio=current_site.name(),
+            job_type='Upload',
+            init_status='WAITING'
+        )
+        sync_manager = self.root().project().get_sync_manager()
+        sync_manager.process(ul_job)
+
+
 class AnimationDepartment(Department):
     _short_name = flow.Param("ani")
 
     build_blocking_scene = flow.Child(BuildBlockingScene)
     create_anim_scene = flow.Child(CreateAnimationScene)
+    create_clean_scene = flow.Child(CreateCleanScene)
 
 
 class RefreshMap(flow.Action):
